new("mPOIAnd", ...). matrizSim:"matrix" with similarity matrix between set and POIs cos.query.docs:"vector" with Similarity of each element of the set wordsInQuery:"ANY" Items used as POIs docs:"matrix" Items of the set objeto:"matrix" 2D Coordinates of the set objetoC:"matrix"2D Coordinates of the set with fisheye effect applied Pcoords:"matrix" 2D coordinates of the POIs PcoordsFI:"matrix" 2D coordinates of the POIs with fisheye effect applied newPcoords:"matrix" Use by tkrplot to allow graphical user interaction newcoords:"numeric" Use by tkrplot to allow graphical user interaction newcoords_1:"numeric" Use by tkrplot to allow graphical user interaction M:"numeric" Fisheye Factor to Apply poisTextCol:"character" Color to be plotted colores:"vector" Color to be plotted poisCircleCol:"character" Color to be plotted linesCol:"character" Color to be plotted itemsCol:"character" Color to be plotted LABELS:"logical" Should POIs be plotted? vscale:"numeric" Vertical size of plot hscale:"numeric" Horizontal size of plot circleCol:"character" Color to be plotted plotCol:"character" Color to be plotted itemsFamily:"character" Font to use pal:"character" Color to be plotted selected:"numeric" Used by tkrplot to allow graphical user interaction circRadio:"numeric" Radio of circle use to select points. IncVscale:"numeric" Animation smoth factor cgnsphrFont:"numeric" Font to use for labelsxClick_old:"numeric" Used by tkrplot to allow graphical user interaction yClick_old:"numeric" Used by tkrplot to allow graphical user interaction wordsInQueryFull:"character" clustered:"logical" should clustered plot be use? "multiPOI", directly.
Class "POI", by class "multiPOI", distance 2.Furnas, George (1986). Generalized Fisheye Views. Human Factors in computing systems, CHI '86 conference proceedings, ACM, New York, pp. 16-23.
Heidi Lam, Ronald A. Rensink, and Tamara Munzner (2006). Effects of 2D Geometric Transformations on Visual Memory. Proc. Applied Perception in Graphics and Visualization (APGV 2006), 119-126, 2006.
Keith Lau, Ron Rensink, and Tamara Munzner (2004). Perceptual Invariance of Nonlinear Focus+Context Transformations. Proc. First Symposium on Applied Perception in Graphics and Visualization (APGV 04) 2004, pp 65-72.
Lamping, J., Rao, R., Pirolli, P. (1995) A Focus+Context Technique Based on Hyperbolic Geometry for Visualizing Large Hierarchies. Proc. ACM Conf. Human Factors in Computing Systems, CHI. ACM. pp, 401-408
plotPOI, POIPlot
POI